#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 comonad
version:              5.0.10
visibility:           public
id:                   comonad-5.0.10-HaxfOLvs78TEnWFj0EheQY
key:                  comonad-5.0.10-HaxfOLvs78TEnWFj0EheQY
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  da67c80b3e585c6ec4045b8580fc6cb7
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-9.6.6/site-local/comonad-5.0.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/comonad-5.0.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/comonad-5.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-comonad
hs-libraries:         HScomonad-5.0.10-HaxfOLvs78TEnWFj0EheQY
depends:
    base-4.18.2.1 containers-0.6.7
    distributive-0.6.3-Loz5FvF1fgP8oPlsEKxJeb
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

